@@ -32,10 +32,12 @@ GetOptions(
     'front-proxy=s' => \@front_proxy,
     'allow-from=s' => \@allow_from,
     'disable-1min-metrics' => \my $disable_short,
+    'enable-float-number' => \my $enable_float_number,
     'with-mysql=s' => \my $mysql,
     'data-dir=s' => \my $data_dir,
     'log-format=s' => \my $log_format,
     'web-max-workers=i' => \my $web_max_workers,
+    'rrdcached=s' => \my $rrdcached,
     "h|help" => \my $help,
 );
 
@@ -76,6 +78,8 @@ $proclet->service(
             root_dir => $root_dir,
             data_dir => $data_dir,
             mysql => $mysql,
+            float_number => $enable_float_number,
+            rrdcached => $rrdcached,
         );
         $worker->run('short');        
     }
@@ -87,7 +91,9 @@ $proclet->service(
         my $worker = GrowthForecast::Worker->new(
             root_dir => $root_dir,
             data_dir => $data_dir,
-            mysql => $mysql
+            mysql => $mysql,
+            float_number => $enable_float_number,
+            rrdcached => $rrdcached,
         );
         $worker->run;
     }
@@ -101,6 +107,8 @@ $proclet->service(
             data_dir => $data_dir,
             short => !$disable_short,
             mysql => $mysql,
+            float_number => $enable_float_number,
+            rrdcached => $rrdcached,
         );
         my $app = builder {
             enable 'Lint';
@@ -235,6 +243,11 @@ Default is empty (allow access from any remote ip address)
 don't generate 1min rrddata and graph
 Default is "1" (enabled) 
 
+=item --enable-float-number
+
+Store numbers of graph data as float rather than integer.
+Default is "0" (disabled)
+
 =item --with-mysql
 
 DB connection setting to store  metadata. format like dbi:mysql:[dbname];hostname=[hostnaem]
@@ -244,6 +257,17 @@ Default is no mysql setting. GrowthForecast save metadata to SQLite
 
 Number of web server processes. Default is 4
 
+=item --rrdcached
+
+rrdcached address. format is like either of
+
+   unix:</path/to/unix.sock>
+   /<path/to/unix.sock>
+   <hostname-or-ip>
+   [<hostname-or-ip>]:<port>
+   <hostname-or-ipv4>:<port>
+
+See the manual of rrdcached for more details. Default does not use rrdcached.
 
 =item -h --help
 
